@@ -1011,6 +1011,10 @@ int VPreProcImp::getStateToken(string& buf) {
 		string rtn; rtn.assign(yyourtext(),yyourleng());
 		refp->nextarg(refp->nextarg()+rtn);
 		goto next_tok;
+	    } else if (tok==VP_STRIFY) {
+		// We must expand stringinfication, when done will return to this state
+		statePush(ps_STRIFY);
+		goto next_tok;
 	    } else {
 		error((string)"Expecting ) or , to end argument list for define reference. Found: "+tokenName(tok));
 		statePop();
